import argparse

from iniconf.creator import IniCreator


def create(args):
    cfg = IniCreator(args.template, args.destination)
    cfg.generate_file()


def cli_main():
    parser = argparse.ArgumentParser()
    subparsers = parser.add_subparsers()

    p_create = subparsers.add_parser('create')
    p_create.add_argument('template')
    p_create.add_argument('destination')
    p_create.set_defaults(func=create)

    args = parser.parse_args()
    args.func(args)


if __name__ == '__main__':
    cli_main()



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages


setup(
    name='iniconf',
    version='0.1.8',
    description='INI Config Creating/Parsing Tool',
    long_description=open('README.md').read(),
    url='https://github.com/brunogfranca/iniconf',
    author='Bruno Franca',
    author_email='bgfranca@gmail.com',
    license=open('LICENSE.txt').read(),
    packages=find_packages(),
    entry_points={
        'console_scripts': ['iniconf = iniconf.cli:cli_main']
    }
)
